#!/usr/bin/env python

import micropython
from micropython.rsvp import raw
import rsvp
import sys

code = None

def show(importer, with_builtins=0, optimisations=None):
    make(importer, with_builtins, optimisations)
    show_code(code)

def make(importer, with_builtins=0, optimisations=None):
    optimisations = optimisations or requested_optimisations
    global code
    code = importer.get_image(with_builtins, optimisations)

def show_code(code):
    for i, x in enumerate(code):
        print i, x

def machine(importer):
    rc = raw(importer.code)
    rm = rsvp.RSVPMachine(rc)
    rm.pc = importer.code_location
    return rm

def attrs(obj):
    for name, attr in obj.items():
        print name, attr

if __name__ == "__main__":
    args = sys.argv[2:]
    i = micropython.Importer(sys.path, "-v" in args)

    if "-omax" in args:
        requested_optimisations = i.supported_optimisations
    else:
        requested_optimisations = []
        for arg in args:
            if arg.startswith("-o"):
                for arg_part in arg[2:].split(","):
                    requested_optimisations.append(arg_part)

    try:
        builtins = i.load_from_file("lib/builtins.py", "__builtins__")
        if len(sys.argv) < 2:
            m = i.load("micropython")
            #m = i.load_from_file("micropython/__init__.py")
        else:
            m = i.load_from_file(sys.argv[1])
    except micropython.ProcessingError, exc:
        print repr(exc)
    else:
        i.vacuum()
        ot = i.get_object_table()
        pt = i.get_parameter_table()

# vim: tabstop=4 expandtab shiftwidth=4
